@@ -1,7 +1,9 @@
 package Data::Sah::Params;
 
-our $DATE = '2020-07-21'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-09-25'; # DATE
+our $DIST = 'Data-Sah-Params'; # DIST
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -116,7 +118,7 @@ sub compile {
 }
 
 1;
-# ABSTRACT: Validate function arguments using Sah schemas
+# ABSTRACT: (DEPRECATED) Validate function arguments using Sah schemas
 
 __END__
 
@@ -126,11 +128,11 @@ __END__
 
 =head1 NAME
 
-Data::Sah::Params - Validate function arguments using Sah schemas
+Data::Sah::Params - (DEPRECATED) Validate function arguments using Sah schemas
 
 =head1 VERSION
 
-This document describes version 0.004 of Data::Sah::Params (from Perl distribution Data-Sah-Params), released on 2020-07-21.
+This document describes version 0.005 of Data::Sah::Params (from Perl distribution Data-Sah-Params), released on 2020-09-25.
 
 =head1 SYNOPSIS
 
@@ -183,7 +185,9 @@ This document describes version 0.004 of Data::Sah::Params (from Perl distributi
 
 =head1 DESCRIPTION
 
-Experimental. Deprecated in favor of L<Params::Sah>.
+B<DEPRECATION NOTICE.> Deprecated in favor of L<Params::Sah>.
+
+Experimental.
 
 Currently mixing positional and named parameters not yet supported.
 
